==> snake-case-0.1.6.tgz: package/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

## [0.1.6](https://github.com/zcorky/zodash/compare/@zodash/snake-case@0.1.5...@zodash/snake-case@0.1.6) (2021-05-03)

**Note:** Version bump only for package @zodash/snake-case





## [0.1.5](https://github.com/zcorky/zodash/compare/@zodash/snake-case@0.1.4...@zodash/snake-case@0.1.5) (2021-03-25)

**Note:** Version bump only for package @zodash/snake-case





## [0.1.4](https://github.com/zcorky/zodash/compare/@zodash/snake-case@0.1.3...@zodash/snake-case@0.1.4) (2021-03-23)

**Note:** Version bump only for package @zodash/snake-case





## 0.1.3 (2020-11-11)

**Note:** Version bump only for package @zodash/snake-case





## 0.1.2 (2020-11-10)

**Note:** Version bump only for package @zodash/snake-case





## 0.1.1 (2020-11-10)

**Note:** Version bump only for package @zodash/snake-case





# 0.1.0 (2020-09-28)


### Features

* **basex:** convert number to baseX (进制转换) ([95a1a2f](https://github.com/zcorky/zodash/commit/95a1a2f361d73de5caa3b8e297c1643e97e40983))





## 0.0.15 (2020-09-18)

**Note:** Version bump only for package @zodash/snake-case





## [0.0.14](https://github.com/zcorky/zodash/compare/@zodash/snake-case@0.0.13...@zodash/snake-case@0.0.14) (2019-12-24)

**Note:** Version bump only for package @zodash/snake-case





## 0.0.13 (2019-12-24)

**Note:** Version bump only for package @zodash/snake-case





## [0.0.12](https://github.com/zcorky/zodash/compare/@zodash/snake-case@0.0.11...@zodash/snake-case@0.0.12) (2019-12-10)

**Note:** Version bump only for package @zodash/snake-case





## [0.0.11](https://github.com/zcorky/zodash/compare/@zodash/snake-case@0.0.10...@zodash/snake-case@0.0.11) (2019-12-09)

**Note:** Version bump only for package @zodash/snake-case





## 0.0.10 (2019-12-08)

**Note:** Version bump only for package @zodash/snake-case





## [0.0.9](https://github.com/zcorky/zodash/compare/@zodash/snake-case@0.0.8...@zodash/snake-case@0.0.9) (2019-10-30)

**Note:** Version bump only for package @zodash/snake-case





## 0.0.8 (2019-10-30)

**Note:** Version bump only for package @zodash/snake-case





## [0.0.7](https://github.com/zcorky/zodash/compare/@zodash/snake-case@0.0.6...@zodash/snake-case@0.0.7) (2019-09-22)

**Note:** Version bump only for package @zodash/snake-case





## 0.0.6 (2019-09-21)

**Note:** Version bump only for package @zodash/snake-case





## 0.0.5 (2019-09-12)

**Note:** Version bump only for package @zodash/snake-case





## [0.0.4](https://github.com/zcorky/zodash/compare/@zodash/snake-case@0.0.3...@zodash/snake-case@0.0.4) (2019-08-18)

**Note:** Version bump only for package @zodash/snake-case





## 0.0.3 (2019-08-18)

**Note:** Version bump only for package @zodash/snake-case





## [0.0.2](https://github.com/zcorky/zodash/compare/@zodash/snake-case@0.0.1...@zodash/snake-case@0.0.2) (2019-06-26)

**Note:** Version bump only for package @zodash/snake-case





## 0.0.1 (2019-06-26)

**Note:** Version bump only for package @zodash/snake-case

==> snake-case-0.1.7.tgz: package/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

## [0.1.7](https://github.com/zcorky/zodash/compare/@zodash/snake-case@0.1.6...@zodash/snake-case@0.1.7) (2021-07-05)

**Note:** Version bump only for package @zodash/snake-case





## [0.1.6](https://github.com/zcorky/zodash/compare/@zodash/snake-case@0.1.5...@zodash/snake-case@0.1.6) (2021-05-03)

**Note:** Version bump only for package @zodash/snake-case

## [0.1.5](https://github.com/zcorky/zodash/compare/@zodash/snake-case@0.1.4...@zodash/snake-case@0.1.5) (2021-03-25)

**Note:** Version bump only for package @zodash/snake-case

## [0.1.4](https://github.com/zcorky/zodash/compare/@zodash/snake-case@0.1.3...@zodash/snake-case@0.1.4) (2021-03-23)

**Note:** Version bump only for package @zodash/snake-case

## 0.1.3 (2020-11-11)

**Note:** Version bump only for package @zodash/snake-case

## 0.1.2 (2020-11-10)

**Note:** Version bump only for package @zodash/snake-case

## 0.1.1 (2020-11-10)

**Note:** Version bump only for package @zodash/snake-case

# 0.1.0 (2020-09-28)

### Features

- **basex:** convert number to baseX (进制转换) ([95a1a2f](https://github.com/zcorky/zodash/commit/95a1a2f361d73de5caa3b8e297c1643e97e40983))

## 0.0.15 (2020-09-18)

**Note:** Version bump only for package @zodash/snake-case

## [0.0.14](https://github.com/zcorky/zodash/compare/@zodash/snake-case@0.0.13...@zodash/snake-case@0.0.14) (2019-12-24)

**Note:** Version bump only for package @zodash/snake-case

## 0.0.13 (2019-12-24)

**Note:** Version bump only for package @zodash/snake-case

## [0.0.12](https://github.com/zcorky/zodash/compare/@zodash/snake-case@0.0.11...@zodash/snake-case@0.0.12) (2019-12-10)

**Note:** Version bump only for package @zodash/snake-case

## [0.0.11](https://github.com/zcorky/zodash/compare/@zodash/snake-case@0.0.10...@zodash/snake-case@0.0.11) (2019-12-09)

**Note:** Version bump only for package @zodash/snake-case

## 0.0.10 (2019-12-08)

**Note:** Version bump only for package @zodash/snake-case

## [0.0.9](https://github.com/zcorky/zodash/compare/@zodash/snake-case@0.0.8...@zodash/snake-case@0.0.9) (2019-10-30)

**Note:** Version bump only for package @zodash/snake-case

## 0.0.8 (2019-10-30)

**Note:** Version bump only for package @zodash/snake-case

## [0.0.7](https://github.com/zcorky/zodash/compare/@zodash/snake-case@0.0.6...@zodash/snake-case@0.0.7) (2019-09-22)

**Note:** Version bump only for package @zodash/snake-case

## 0.0.6 (2019-09-21)

**Note:** Version bump only for package @zodash/snake-case

## 0.0.5 (2019-09-12)

**Note:** Version bump only for package @zodash/snake-case

## [0.0.4](https://github.com/zcorky/zodash/compare/@zodash/snake-case@0.0.3...@zodash/snake-case@0.0.4) (2019-08-18)

**Note:** Version bump only for package @zodash/snake-case

## 0.0.3 (2019-08-18)

**Note:** Version bump only for package @zodash/snake-case

## [0.0.2](https://github.com/zcorky/zodash/compare/@zodash/snake-case@0.0.1...@zodash/snake-case@0.0.2) (2019-06-26)

**Note:** Version bump only for package @zodash/snake-case

## 0.0.1 (2019-06-26)

**Note:** Version bump only for package @zodash/snake-case
